@@ -57,3 +57,7 @@ FORMSET_TEMPLATE_NAMEID = 'NNNNN'
 MANAGEMENT_FORMSET_STRINGS = [FORMSET_TEMPLATE_NAMEID,
                               '-TOTAL_FORMS', '-INITIAL_FORMS',
                               '-MAX_NUM_FORMS','-MIN_NUM_FORMS']
+
+CAPTCHA_DEFAULT_LANG = 'en'
+
+CUSTOM_WIDGETS_IN_FORMSETS = True
